@@ -23,6 +23,11 @@
 typedef struct _sem {
 	int		tid;
 	sem_t		ss;
+
+	char *		lock_file;
+	int		lock_line;
+	char *		unlock_file;
+	int		unlock_line;
 } _SEM;
 
 #endif /* DEADLOCK_CHECK */
@@ -34,13 +39,17 @@ typedef struct _sem {
 #ifndef ___M_THREAD_2_END_H___
 #define ___M_THREAD_2_END_H___
 
+/*
 #define SCHED_POLICY	SCHED_RR
+*/
+#define SCHED_POLICY	SCHED_OTHER
 
 typedef struct sw_hash {
 	struct sw_hash *	next;
 	unsigned int		key;
 	int			cnt;
 	sem_t			sem;
+	int			tid;
 } SW_HASH;
 
 
