@@ -46,9 +46,15 @@ set_ignore_chld()
 }
 
 void
-set_alarm_mask(int flags)
+all_signal_mask_posix()
 {
 	all_signal_mask(1,45);
+}
+
+void
+set_alarm_mask(int flags)
+{
+	all_signal_mask_posix();
 	signal(SIGALRM,sigalarm_handler);
 	signal(SIGPIPE,sigpipe_handler);
 	signal(SIGLWP,siglwp_handler);
