@@ -54,6 +54,8 @@ STREAM * s_open_file_descripter();
 S_TABLE s_file_table = {
 	'f',
 	0,
+	{0,0},
+	NULL,
 	s_open_file_descripter,
 	s_close_file,
 	s_write_file,
@@ -113,6 +115,7 @@ void _s_open(STREAM * s,int mode);
 
 	lock_task(stream_lock);
 	_s_open(ret,mode);
+
 	unlock_task(stream_lock,"s_open_descripter");
 	return ret;
 }
