@@ -116,6 +116,7 @@ RESOURCE * r;
 			gc_gb_sexp(r->h.meta);
 			gc_gb_sexp(r->h.incremental_error);
 			gc_gb_sexp(r->h.initial_error);
+			gc_gb_sexp(r->h.data);
 			switch ( r->h.type ) {
 			case RT_DRAW_GB:
 				gc_gv_draw(r);
@@ -674,6 +675,7 @@ XL_SEXP * s, * rec, * tag;
 int minrect_flag;
 UNIT_ENV * uenv;
 L_CHAR * f;
+XL_SEXP * _mod;
 
 	setup_c_unit(
 		&r->h.cu,-1,f=ll_copy_str(get_url_str2(&r->h.entry),123),
@@ -703,7 +705,12 @@ L_CHAR * f;
 						-1));
 			minrect_flag = 1;
 			get_minrect(&r->h.cu,&r->h.minrect,get_el(rec,1));
-
+		}
+		if ( l_strcmp(tag->symbol.data,l_string(std_cm,
+				"modify")) == 0 ) {
+			_mod = get_el(rec,1);
+			if ( get_type(_mod) == XLT_INTEGER )
+				r->h.modify = _mod->integer.data;
 		}
 	}
 	if ( minrect_flag == 0 ) {
