@@ -879,6 +879,13 @@ void set_gv_resource(int id,XLISP_ENV * env);
 void load_resource_list(LOAD_RESOURCE_WORK *,int,int);
 void _load_resource_list(int ses);
 
+
+#define CRS_NOTHING		0
+#define CRS_LOADING		1
+#define CRS_EXIST		4
+#define CRS_ERROR		5
+#define CRS_MAX			6
+
 void free_lrw_que_next(LOAD_RESOURCE_WORK *);
 void free_lrw_req_next(LOAD_RESOURCE_WORK *);
 LOAD_RESOURCE_WORK * new_lrw(LOAD_RESOURCE_WORK * w);
@@ -928,6 +935,7 @@ extern RW_LOCK		resource_lock;
 */
 extern SEM 		status_lock;
 
+int check_lrw_status(LOAD_RESOURCE_WORK * w,int * sts,int len,int flags,int mask);
 
 #endif
 
