@@ -21,6 +21,7 @@
 #include	<stdlib.h>
 #include	"memory_debug.h"
 #include	"lock_level.h"
+#include	"save_global.h"
 
 #ifndef DONT_USE_LOCK
 #include	"task.h"
@@ -43,11 +44,8 @@ int i;
 
 #ifdef MEMORY_DEBUG
 
-#define ALIGN	2
+#define ALIGN	4
 
-char*  type_msg[MT_MAX];
-int memory_type[MT_MAX];
-int memory_size[MT_MAX];
 int flag;
 
 #ifndef DONT_USE_LOCK
@@ -77,39 +75,16 @@ init_type_msg()
 		return;
 	flag = 1;
 	NEW_LOCK;
-	type_msg[18] = "gc_stack_routine.c/thread";
-	type_msg[19] = "gc_stack_routine.c/stack";
-	type_msg[20] = "gc_stack_routine.c/lst in stack";
-	type_msg[99] = "euc_workarea";
-	type_msg[101] = "l_string.c/ret";
-	type_msg[120] = "copy_str.c";
-	type_msg[126] = "ll_copy_str.c/ret";
-	type_msg[179] = "account.c/ua";
-	type_msg[180] = "agent.c/al";
-	type_msg[184] = "init.c/S_ACCEPT";
-	type_msg[195] = "min_memory.c/module";
-	type_msg[196] = "accept_connection.c/key->s";
-	type_msg[1000] = "get_url_filepath";
-	type_msg[1001] = "get_url_str2";
-	type_msg[1002] = "MAP_PATH_INFO";
-	type_msg[1003] = "MAP_PATH_TABLE";
-	type_msg[1010] = "in the set_buffer";
-	type_msg[1030] = "nl_copy_str";
-	type_msg[1500] = "RECT_NODE";
-	type_msg[1501] = "insert_point";
-	type_msg[1502] = "OBJ";
-	type_msg[1503] = "draw_string/data";
-	type_msg[1504] = "INFO_LIST";
-	type_msg[1505] = "SYMBOL_INDICATE";
-	type_msg[1506] = "CODE/AVT";
-	type_msg[1507] = "RT_OBJ_LIST";
-	type_msg[1508] = "PE after";
-	type_msg[1509] = "SI ref ll_copy_str 1";
-	type_msg[1510] = "SI ref ll_copy_str 2";
-	type_msg[1511] = "radar_lump ll_copy_str 1";
-	type_msg[1512] = "radar_lump crdpath ll_copy_Str 1";
-	type_msg[1513] = "radar_lump crdpath ll_copy_str 2";
-	type_msg[1514] = "radar_lump ll_copy_str 2";
+}
+
+void
+init_d_alloc()
+{
+
+	SG_TITLE;
+	sg("char**",		"last_free_file",	&last_free_file);
+	sg("int*",		"last_free_line",	&last_free_line);
+	sg("unsigned char",	"last_free_ptr",	&last_free_ptr);
 }
 
 
@@ -211,10 +186,8 @@ unsigned char * pp, * qq;
 		er_panic("xx_d_f_ree(1)");
 	ret[0] = (int)file;
 	ret[1] = line;
-/*
-	memory_type[ret[0]] --;
-	memory_size[ret[0]] -= size;
-*/
+	ret[2] = (int)file;
+	ret[3] = line;
 	for ( p = ptr, i = size ; i > 0 ; i -- )
 		*p++ = last_free_ptr;
 	free(ret);
@@ -251,7 +224,7 @@ indicate_md()
 {
 int i;
 int fg;
-	printf("----\n");
+/*	printf("----\n");
 	fg = 0;
 	for ( i = 0 ; i < MT_MAX ; i ++ ) {
 		if ( memory_type[i] == 0 )
@@ -263,6 +236,7 @@ int fg;
 	}
 	if ( fg )
 		printf("\n");
+*/
 }
 
 
@@ -274,7 +248,7 @@ int i;
 int fg;
 int max;
 int cur_max;
-	printf("----\n");
+/*	printf("----\n");
 	fg = 0;
 	max = 0x7fffffff;
 	for ( ; max ; ) {
@@ -302,6 +276,7 @@ int cur_max;
 	}
 	if ( fg )
 		printf("\n");
+*/
 }
 
 
@@ -310,7 +285,7 @@ indicate_md_in_buf(char ** ptr,int * cnt,int * size)
 {
 int i;
 int fg;
-	fg = 0;
+/*	fg = 0;
 	for ( i = 0 ; i < MT_MAX ; i ++ ) {
 		if ( memory_type[i] == 0 ) {
 			ptr[i] = 0;
@@ -334,6 +309,7 @@ int fg;
 		fg = 1;
 		
 	}
+*/
 }
 
 
