@@ -29,7 +29,7 @@ PDB * p;
 int fid;
 char * _f;
 	_f = change_delim_str(filename);
-	fid = open(_f,oflags,mode);
+	fid = u_open(_f,oflags,mode);
 	if ( fid < 0 ) {
 		p = 0;
 		goto end;
@@ -37,7 +37,7 @@ char * _f;
 	p = d_alloc(sizeof(*p),2);
 	p->fid = fid;
 	p->flags = flags;
-	lseek(fid,0,SEEK_SET);
+	u_lseek(fid,0,SEEK_SET);
 	p->fofs = 0;
 	p->request = 0;
 	p->next_request = 0;
